@@ -1237,6 +1237,28 @@ const tI18nPhrase Phrases[] = {
     "",
     "Pejmenovn/pesun selhal!",
   },
+  { "Use cutter queue",
+    "Schnittwarteschlange benutzen",
+    "",
+    "",
+    "",
+    "",
+    "",
+    "",
+    "",
+    "",
+    "",
+    "",
+    "",
+    "",
+    "",
+    "",
+    "",
+    "",
+    "",
+    "",
+    "",
+  },
   { NULL }
   };
 
