@@ -3,7 +3,7 @@
  *
  * See the README file for copyright information and how to reach the author.
  *
- * $Id: protocolext.h,v 1.8 2007/10/21 17:32:43 ajhseppa Exp $
+ * $Id: protocolext.h,v 1.9 2008/01/04 23:36:37 ajhseppa Exp $
  */
 
 #ifndef __IPTV_PROTOCOLEXT_H
@@ -28,10 +28,10 @@ public:
   cIptvProtocolExt();
   virtual ~cIptvProtocolExt();
   int Read(unsigned char* *BufferAddr);
-  virtual bool Set(const char* Location, const int Parameter, const int Index);
-  virtual bool Open(void);
-  virtual bool Close(void);
-  virtual cString GetInformation(void);
+  bool Set(const char* Location, const int Parameter, const int Index);
+  bool Open(void);
+  bool Close(void);
+  cString GetInformation(void);
 };
 
 #endif // __IPTV_PROTOCOLEXT_H
