@@ -3,7 +3,7 @@
  *
  * See the README file for copyright information and how to reach the author.
  *
- * $Id: setup.h,v 1.16 2007/10/20 17:26:46 rahrenbe Exp $
+ * $Id: setup.h,v 1.18 2008/01/20 16:15:14 rahrenbe Exp $
  */
 
 #ifndef __IPTV_SETUP_H
@@ -23,6 +23,9 @@ private:
   int numDisabledFilters;
   int disabledFilterIndexes[SECTION_FILTER_TABLE_SIZE];
   const char *disabledFilterNames[SECTION_FILTER_TABLE_SIZE];
+#if defined(APIVERSNUM) && APIVERSNUM >= 10513
+  cVector<const char*> help;
+#endif
 
   eOSState EditChannel(void);
   eOSState ShowInfo(void);
