@@ -16,7 +16,13 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: i18n.cpp 5687 2007-08-12 01:11:25Z svntcreutz $
+ * $Id: i18n.cpp 6565 2007-12-27 21:44:16Z svntobi $
+ *
+ */
+
+/* 
+ * Translators:
+ *     - Italian translations provided by Gringo <vdr-italian@tiscali.it>
  *
  */
 
@@ -28,7 +34,7 @@ const tI18nPhrase Phrases[] =
         "Failed to load MenuOrg's config file!",
         "Konnte die MenuOrg Konfigurationsdatei nicht laden",
         "",
-        "",
+        "Impossibile caricare il file di configurazione MenuOrg",
         "",
         "",
         "",
