@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: i18n.h 5809 2007-08-19 09:13:05Z svntobi $
+ * $Id: i18n.h 6560 2007-12-11 00:03:15Z svntobi $
  *
  */
 
@@ -28,8 +28,4 @@
 
 extern const tI18nPhrase Phrases[];
 
-#if VDRVERSNUM < 10509
-#define trVDR(s) tr(s)
-#endif
-
 #endif
