@@ -16,13 +16,14 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: osditemdefinition.cpp 5832 2007-08-19 20:17:20Z svntobi $
+ * $Id: osditemdefinition.cpp 6560 2007-12-11 00:03:15Z svntobi $
  *
  */
 
 #include "osditemdefinition.h"
 
-OsdItemDefinition::OsdItemDefinition(cOsdItem* osdItem)
+OsdItemDefinition::OsdItemDefinition(MenuNode* menuNode, cOsdItem* osdItem)
+ :MenuItemDefinition(menuNode)
 {
     _osdItem = osdItem;
 }
