@@ -16,22 +16,22 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: osditemdefinition.h 5832 2007-08-19 20:17:20Z svntobi $
+ * $Id: osditemdefinition.h 6560 2007-12-11 00:03:15Z svntobi $
  *
  */
 
 #ifndef ___OSDITEMDEFINITION_H
 #define ___OSDITEMDEFINITION_H
 
-#include <vdr/mainmenuitemsprovider.h>
+#include "menuitemdefinition.h"
 
-class OsdItemDefinition: public IMenuItemDefinition
+class OsdItemDefinition: public MenuItemDefinition
 {
     private:
         cOsdItem* _osdItem;
 
     public:
-        OsdItemDefinition(cOsdItem* osdItem);
+        OsdItemDefinition(MenuNode* menuNode, cOsdItem* osdItem);
         virtual bool IsCustomOsdItem();
         virtual bool IsPluginItem();
         virtual cOsdItem* CustomOsdItem();
