@@ -16,13 +16,14 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: pluginitemdefinition.cpp 5832 2007-08-19 20:17:20Z svntobi $
+ * $Id: pluginitemdefinition.cpp 6560 2007-12-11 00:03:15Z svntobi $
  *
  */
 
 #include "pluginitemdefinition.h"
 
-PluginItemDefinition::PluginItemDefinition(const char* mainMenuEntry, int pluginIndex)
+PluginItemDefinition::PluginItemDefinition(MenuNode* menuNode, const char* mainMenuEntry, int pluginIndex)
+ :MenuItemDefinition(menuNode)
 {
     _mainMenuEntry = mainMenuEntry;
     _pluginIndex = pluginIndex; 
