@@ -16,23 +16,23 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: pluginitemdefinition.h 5832 2007-08-19 20:17:20Z svntobi $
+ * $Id: pluginitemdefinition.h 6560 2007-12-11 00:03:15Z svntobi $
  *
  */
 
 #ifndef ___PLUGINITEMDEFINITION_H
 #define ___PLUGINITEMDEFINITION_H
 
-#include <vdr/mainmenuitemsprovider.h>
+#include "menuitemdefinition.h"
 
-class PluginItemDefinition: public IMenuItemDefinition
+class PluginItemDefinition: public MenuItemDefinition
 {
     private:
         const char* _mainMenuEntry;
         int _pluginIndex;
 
     public:
-        PluginItemDefinition(const char* mainMenuEntry, int pluginIndex);
+        PluginItemDefinition(MenuNode* menuNode, const char* mainMenuEntry, int pluginIndex);
         virtual bool IsCustomOsdItem();
         virtual bool IsPluginItem();
         virtual cOsdItem* CustomOsdItem();
