@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: submenunode.cpp 5940 2007-08-23 21:14:48Z svntobi $
+ * $Id: submenunode.cpp 6560 2007-12-11 00:03:15Z svntobi $
  *
  */
 
@@ -32,7 +32,7 @@ SubMenuNode::SubMenuNode(std::string text)
 
 IMenuItemDefinition* SubMenuNode::CreateMenuItemDefinition()
 {
-    return new OsdItemDefinition(new cOsdItem(_text.c_str(), osUser1));
+    return new OsdItemDefinition(this, new cOsdItem(_text.c_str(), osUser1));
 }
 
 bool SubMenuNode::IsHidden()
