@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: systemmenunode.cpp 5940 2007-08-23 21:14:48Z svntobi $
+ * $Id: systemmenunode.cpp 6560 2007-12-11 00:03:15Z svntobi $
  *
  */
 
@@ -25,6 +25,10 @@
 #include "osditemdefinition.h"
 #include "childlock.h"
 
+#if VDRVERSNUM < 10509
+#define trVDR(s) tr(s)
+#endif
+
 SystemMenuNode::SystemMenuNode(std::string text, eOSState state)
 {
     _text = text;
@@ -33,7 +37,7 @@ SystemMenuNode::SystemMenuNode(std::string text, eOSState state)
 
 IMenuItemDefinition* SystemMenuNode::CreateMenuItemDefinition()
 {
-    return new OsdItemDefinition(new cOsdItem(trVDR(_text.c_str()), _state));
+    return new OsdItemDefinition(this, new cOsdItem(trVDR(_text.c_str()), _state));
 }
 
 bool SystemMenuNode::IsHidden()
