@@ -457,26 +457,26 @@ void PatFilter::Process(u_short Pid, u_char Tid, const u_char *Data, int Length)
                             case SI::AC3DescriptorTag:
                                  dpid = stream.getPid();
                                  break;
-                            case SI::SubtitlingDescriptorTag:
-                                 if (NumSpids < MAXSPIDS) {
-                                    SI::SubtitlingDescriptor *sd = (SI::SubtitlingDescriptor *)d;
-                                    SI::SubtitlingDescriptor::Subtitling sds;
-                                    Spids[NumSpids] = stream.getPid();
-                                    char *s = SLangs[NumSpids];
-                                    int n = 0;
-                                    for (SI::Loop::Iterator it; sd->subtitlingLoop.getNext(sds, it); ) {
-                                      if (sds.languageCode[0]) {
-                                         if (n > 0)
-                                            *s++ = '+';
-                                         strn0cpy(s, I18nNormalizeLanguageCode(sds.languageCode), MAXLANGCODE1);
-                                         s += strlen(s);
-                                         if (n++ > 1)
-                                            break;
-                                         }
-                                      }
+		            case SI::SubtitlingDescriptorTag:
+			         if (NumSpids < MAXSPIDS) {
+				    Spids[NumSpids] = stream.getPid();
+				    SI::SubtitlingDescriptor *sd = (SI::SubtitlingDescriptor *)d;
+				    SI::SubtitlingDescriptor::Subtitling sub;
+				    char *s = SLangs[NumSpids];
+				    int n = 0;
+				    for (SI::Loop::Iterator it; sd->subtitlingLoop.getNext(sub, it); ) {
+				        if (sub.languageCode[0]) {
+					   if (n > 0)
+                                              *s++ = '+';
+					   strn0cpy(s, I18nNormalizeLanguageCode(sub.languageCode), MAXLANGCODE1);
+					   s += strlen(s);
+					   if (n++ > 1)
+					      break;
+					   }
+                                        }
                                     NumSpids++;
-                                    }
-                                 break;
+				    }
+				 break;
                             case SI::TeletextDescriptorTag:
                                  Tpid = stream.getPid();
                                  break;
