@@ -10,7 +10,7 @@
 #include "tools.h"
 
 #ifdef USE_PLUGIN_AVARDS
-#include "../avards/avards_services.h"
+#include "services/avards.h"
 #endif
 
 #include <stdlib.h>
@@ -61,7 +61,7 @@ cEnigmaConfig::cEnigmaConfig() : showAuxInfo(1), showLogo(1), showVps(1), showSy
                                  imageWidth(120), imageHeight(80), imageExtension(0), fullTitleWidth(0),
                                  useTextEffects(0), scrollDelay(50), scrollPause(1500), scrollMode(0),
                                  blinkPause(1000), scrollInfo(1), scrollListItem(1), scrollOther(1), scrollTitle(1),
-                                 dynOsd(0), statusLineMode(0)
+                                 dynOsd(0), statusLineMode(0), showWssSymbols(0), showStatusSymbols(1)
 {
   memset(logoDir, 0, sizeof(logoDir));
   memset(strImagesDir, 0, sizeof(strImagesDir));
@@ -145,7 +145,7 @@ const cFont *cEnigmaConfig::GetFont(int id, const cFont *pFontCur)
         if (FontCache.Load(string(strFontsDir) + "/" + string(allFonts[id].Name), cachename, allFonts[id].Size, Setup.OSDLanguage, allFonts[id].Width)) {
 #else
         asprintf(&cachename, "%s_%d_%d_%s", allFonts[id].Name, allFonts[id].Size, allFonts[id].Width, Setup.OSDLanguage);
-        if (FontCache.Load(string(strFontsDir) + "/" + string(allFonts[id].Name), cachename, allFonts[id].Size, allFonts[id].Width)) {
+        if (FontCache.Load(string(allFonts[id].Name), cachename, allFonts[id].Size, allFonts[id].Width)) {
 #endif
           res = FontCache.GetFont(cachename);
         } else {
