@@ -65,6 +65,19 @@ cPluginVompserver::cPluginVompserver(void)
 bool cPluginVompserver::Start(void)
 {
   // Start any background activities the plugin shall perform.
+  
+  if (!configDir)
+  {
+    const char* vdrret = cPlugin::ConfigDirectory("vompserver");
+    if (!vdrret)
+    {
+      dsyslog("VOMP: Could not get config dir from VDR");
+      return false;
+    }
+    configDir = new char[strlen(vdrret)+1];
+    strcpy(configDir, vdrret);
+  }
+  
   int success = mvpserver.run(configDir);
   if (success) return true;
   else return false;
@@ -74,6 +87,7 @@ cPluginVompserver::~cPluginVompserver()
 {
   // Clean up after yourself!
   mvpserver.stop();
+  if (configDir) delete[] configDir;
 }
 
 const char *cPluginVompserver::CommandLineHelp(void)
@@ -92,7 +106,15 @@ bool cPluginVompserver::ProcessArgs(int argc, char *argv[])
   {
     if (c == 'c')
     {
-      configDir = optarg;
+      const char* vdrret = cPlugin::ConfigDirectory(optarg);
+      if (!vdrret)
+      {
+        dsyslog("VOMP: Could not get config dir from VDR");
+        return false;
+      }
+    
+      configDir = new char[strlen(vdrret)+1];
+      strcpy(configDir, vdrret);
     }
     else
     {
