@@ -232,7 +232,7 @@ cTextBox::SetText(int num, ...)
 	 */
 	va_start(ap, num);
 	for (numLines = 0; numLines < num; numLines++) {
-		char *s = va_arg(ap, char *);
+		const char *s = va_arg(ap, char *);
 		if (s == NULL) {
 			s = "";
 		}
@@ -754,7 +754,7 @@ cInfoBox::FormatText(void)
 #define DTBOX_WIDTH			314
 #define DTBOX_HEIGHT			20
 
-char *numToDay[7] = {
+const char *numToDay[7] = {
 	"Sun",
 	"Mon",
 	"Tue",
