@@ -4,7 +4,7 @@
  * See the main source file 'vdr.c' for copyright information and
  * how to reach the author.
  *
- * $Id: config.c 1.157 2007/10/06 14:28:58 kls Exp $
+ * $Id: config.c 1.158 2007/11/25 13:46:27 kls Exp $
  */
 
 #include "config.h"
@@ -296,13 +296,16 @@ cSetup::cSetup(void)
   CurrentDolby = 0;
   InitialChannel = 0;
   InitialVolume = -1;
+  EmergencyExit = 1;
   ShowRecDate = 1;
   ShowRecTime = 1;
   ShowRecLength = 0;
   ShowProgressBar = 0;
   MenuCmdPosition = 0;
+//ML
   VerboseLNBlog = 0;
   for (int i = 0; i < MAXDEVICES; i++) CardUsesLNBnr[i] = i + 1;
+//ML-End
 }
 
 cSetup& cSetup::operator= (const cSetup &s)
@@ -484,6 +487,7 @@ bool cSetup::Parse(const char *Name, const char *Value)
   else if (!strcasecmp(Name, "CurrentDolby"))        CurrentDolby       = atoi(Value);
   else if (!strcasecmp(Name, "InitialChannel"))      InitialChannel     = atoi(Value);
   else if (!strcasecmp(Name, "InitialVolume"))       InitialVolume      = atoi(Value);
+  else if (!strcasecmp(Name, "EmergencyExit"))       EmergencyExit      = atoi(Value);
   else if (!strcasecmp(Name, "ShowRecDate"))         ShowRecDate        = atoi(Value);
   else if (!strcasecmp(Name, "ShowRecTime"))         ShowRecTime        = atoi(Value);
   else if (!strcasecmp(Name, "ShowRecLength"))       ShowRecLength      = atoi(Value);
@@ -491,6 +495,7 @@ bool cSetup::Parse(const char *Name, const char *Value)
   else if (!strcasecmp(Name, "MenuCmdPosition"))     MenuCmdPosition    = atoi(Value);
   else if (!strcasecmp(Name, "CutTimePatchEnabled")) CutTimePatchEnabled= atoi(Value);
   else
+//ML
   if (!strcasecmp(Name, "VerboseLNBlog")) VerboseLNBlog = atoi(Value);
   else {
      char tmp[20];
@@ -504,6 +509,7 @@ bool cSetup::Parse(const char *Name, const char *Value)
          }
      return result;
   }
+//ML-End
   return true;
 }
 
@@ -590,13 +596,15 @@ bool cSetup::Save(void)
   Store("CurrentDolby",       CurrentDolby);
   Store("InitialChannel",     InitialChannel);
   Store("InitialVolume",      InitialVolume);
+  Store("EmergencyExit",      EmergencyExit);
   Store("ShowRecDate",        ShowRecDate);
   Store("ShowRecTime",        ShowRecTime);
   Store("ShowRecLength",      ShowRecLength);
   Store("ShowProgressBar",    ShowProgressBar);
   Store("MenuCmdPosition",    MenuCmdPosition);
   Store("CutTimePatchEnabled",CutTimePatchEnabled);
-  Store("VerboseLNBlog",      VerboseLNBlog);
+//ML
+  Store("VerboseLNBlog",       VerboseLNBlog);
   char tmp[20];
   if (cDevice::NumDevices() > 1) {
      for (int i = 1; i <= cDevice::NumDevices(); i++) {
@@ -604,6 +612,7 @@ bool cSetup::Save(void)
          Store(tmp, CardUsesLNBnr[i - 1]);
          }
      }
+//ML-End
 
   Sort();
 
