@@ -4,7 +4,7 @@
  * See the main source file 'vdr.c' for copyright information and
  * how to reach the author.
  *
- * $Id: config.h 1.301 2007/11/10 13:38:19 kls Exp $
+ * $Id: config.h 1.303 2007/11/25 13:45:48 kls Exp $
  */
 
 #ifndef __CONFIG_H
@@ -22,13 +22,13 @@
 
 // VDR's own version number:
 
-#define VDRVERSION  "1.5.12"
-#define VDRVERSNUM   10512  // Version * 10000 + Major * 100 + Minor
+#define VDRVERSION  "1.5.13"
+#define VDRVERSNUM   10513  // Version * 10000 + Major * 100 + Minor
 
 // The plugin API's version number:
 
-#define APIVERSION  "1.5.12"
-#define APIVERSNUM   10512  // Version * 10000 + Major * 100 + Minor
+#define APIVERSION  "1.5.13"
+#define APIVERSNUM   10513  // Version * 10000 + Major * 100 + Minor
 
 #define PLUGINPARAMPATCHVERSNUM 1
 
@@ -40,7 +40,7 @@
 
 #define MAINMENUHOOKSVERSNUM 1.0
 
-#define LIEMIKUUTIO  116
+#define LIEMIKUUTIO  117
 
 #define MAXPRIORITY 99
 #define MAXLIFETIME 99
@@ -50,7 +50,7 @@
 #define MINOSDHEIGHT 324
 #define MAXOSDHEIGHT 567
 
-#define MAXDEVICES 16 // the maximum number of devices in the system
+#define MAXDEVICES         16 // the maximum number of devices in the system
 
 #define MaxFileName 256
 #define MaxSkinName 16
@@ -280,10 +280,13 @@ public:
   int CurrentDolby;
   int InitialChannel;
   int InitialVolume;
+  int EmergencyExit;
   int ShowRecDate, ShowRecTime, ShowRecLength, ShowProgressBar, MenuCmdPosition;
   int CutTimePatchEnabled;
+//ML
   int VerboseLNBlog;
   int CardUsesLNBnr[MAXDEVICES];
+//ML-End
   int __EndData__;
   cSetup(void);
   cSetup& operator= (const cSetup &s);
