@@ -63,7 +63,7 @@ const char *LanguageCodeList[] = {
   NULL
   };
 
-const char *I18nLocaleDir = LOCDIR;
+static const char *I18nLocaleDir = LOCDIR;
 
 static cStringList LanguageLocales;
 static cStringList LanguageNames;
@@ -100,8 +100,10 @@ static void SetEnvLanguage(const char *Locale)
   ++_nl_msg_cat_cntr;
 }
 
-void I18nInitialize(void)
+void I18nInitialize(const char *LocaleDir)
 {
+  if (LocaleDir)
+     I18nLocaleDir = LocaleDir;
   LanguageLocales.Append(strdup(I18N_DEFAULT_LOCALE));
   LanguageNames.Append(strdup(SkipContext(LanguageName)));
   LanguageCodes.Append(strdup(LanguageCodeList[0]));
