@@ -4,7 +4,7 @@
  * See the main source file 'vdr.c' for copyright information and
  * how to reach the author.
  *
- * $Id: tools.h 1.108 2007/08/25 14:16:39 kls Exp $
+ * $Id: tools.h 1.110 2008/01/13 11:22:26 kls Exp $
  */
 
 #ifndef __TOOLS_H
@@ -159,6 +159,7 @@ public:
   operator const char * () const { return s; } // for use in (const char *) context
   const char * operator*() const { return s; } // for use in (const void *) context (printf() etc.)
   cString &operator=(const cString &String);
+  cString &Truncate(int Index); ///< Truncate the string at the given Index (if Index is < 0 it is counted from the end of the string).
   static cString sprintf(const char *fmt, ...) __attribute__ ((format (printf, 1, 2)));
   };
 
@@ -470,7 +471,10 @@ public:
        memmove(&data[Index], &data[Index + 1], (size - Index) * sizeof(T));
     size--;
   }
-  virtual void Clear(void) {}
+  virtual void Clear(void)
+  {
+    size = 0;
+  }
   void Sort(__compar_fn_t Compare)
   {
     qsort(data, size, sizeof(T), Compare);
